@@ -26,8 +26,8 @@ Generic Access to Thruks Config
 
 ######################################
 
-our $VERSION = '3.27.20260216';
-our $GIT_HASH = "dfe98c194"; # set by dailydist make target
+our $VERSION = '3.26';
+our $GIT_HASH = ""; # set by dailydist make target
 
 our $config;
 our $project_root = home() || confess('could not determine project_root from inc.');
@@ -35,7 +35,7 @@ our $project_root = home() || confess('could not determine project_root from inc
 my $base_defaults = {
     'name'                                  => 'Thruk',
     'fileversion'                           => $VERSION,
-    'released'                              => 'February 16, 2026',
+    'released'                              => 'February 06, 2026',
     'compression_format'                    => 'gzip',
     'ENCODING'                              => 'utf-8',
     'image_path'                            => $project_root.'/root/thruk/images',
